"use strict";
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GeneralObjectCoder = exports.BsonObjectCoder = void 0;
const _tct_flatten_destructured_imports_1 = __importStar(require("bson"));
var BSON = _tct_flatten_destructured_imports_1;
const _tct_flatten_destructured_imports_2 = __importStar(require("protobufjs"));
var Writer = _tct_flatten_destructured_imports_2.Writer;
var Reader = _tct_flatten_destructured_imports_2.Reader;
const _tct_flatten_destructured_imports_3 = __importStar(require("./coders"));
var Coder = _tct_flatten_destructured_imports_3.Coder;
var Context = _tct_flatten_destructured_imports_3.Context;
var ProtoContext = _tct_flatten_destructured_imports_3.ProtoContext;
var globalRegistry = _tct_flatten_destructured_imports_3.globalRegistry;
const _tct_flatten_destructured_imports_4 = __importStar(require("./standard_coders"));
var BoolCoder = _tct_flatten_destructured_imports_4.BoolCoder;
var DoubleCoder = _tct_flatten_destructured_imports_4.DoubleCoder;
var StrUtf8Coder = _tct_flatten_destructured_imports_4.StrUtf8Coder;
var VarIntCoder = _tct_flatten_destructured_imports_4.VarIntCoder;
const _tct_flatten_destructured_imports_5 = __importStar(require("./required_coders"));
var IterableCoder = _tct_flatten_destructured_imports_5.IterableCoder;
const _tct_flatten_destructured_imports_6 = __importStar(require("../proto/beam_runner_api"));
var runnerApi = _tct_flatten_destructured_imports_6;
/**
 * A Coder<T> that encodes a javascript object with BSON.
 */
class BsonObjectCoder {
    encode(element, writer, context) {
        const buff = BSON.serialize(element);
        writer.bytes(buff);
    }
    decode(reader, context) {
        const encoded = reader.bytes();
        return BSON.deserialize(encoded);
    }
    toProto(pipelineContext) {
        return {
            spec: {
                urn: BsonObjectCoder.URN,
                payload: new Uint8Array(),
            },
            componentCoderIds: [],
        };
    }
}
exports.BsonObjectCoder = BsonObjectCoder;
BsonObjectCoder.URN = "beam:coder:bsonjs:v1";
globalRegistry().register(BsonObjectCoder.URN, BsonObjectCoder);
class NumberOrFloatCoder {
    constructor() {
        this.intCoder = new VarIntCoder();
        this.doubleCoder = new DoubleCoder();
    }
    encode(element, writer, context) {
        if (element % 1) {
            writer.string("f");
            this.doubleCoder.encode(element, writer, context);
        }
        else {
            writer.string("i");
            this.intCoder.encode(element, writer, context);
        }
    }
    decode(reader, context) {
        const typeMarker = reader.string();
        if (typeMarker === "f") {
            return this.doubleCoder.decode(reader, context);
        }
        else {
            return this.intCoder.decode(reader, context);
        }
    }
    toProto(pipelineContext) {
        return {
            spec: {
                urn: NumberOrFloatCoder.URN,
                payload: new Uint8Array(),
            },
            componentCoderIds: [],
        };
    }
}
NumberOrFloatCoder.URN = "beam:coder:numbersforjs:v1";
/**
 * A Coder<T> that encodes common javascript types such as strings, numbers,
 * nulls, or objects.
 */
class GeneralObjectCoder {
    constructor() {
        this.codersByType = {
            string: new StrUtf8Coder(),
            number: new NumberOrFloatCoder(),
            object: new BsonObjectCoder(),
            boolean: new BoolCoder(),
            array: new IterableCoder(this),
        };
        // This is a map of type names to type markers. It maps a type name to its
        // marker within a stream.
        this.typeMarkers = {
            string: "S",
            number: "N",
            object: "O",
            boolean: "B",
            array: "A",
        };
        // This is a map of type markers to type names. It maps a type marker to its
        // type name.
        this.markerToTypes = {
            S: "string",
            N: "number",
            O: "object",
            B: "boolean",
            A: "array",
        };
    }
    encode(element, writer, context) {
        if (element === null || element === undefined) {
            // typeof is "object" but BSON can't handle it.
            writer.string("Z");
        }
        else {
            const type = Array.isArray(element) ? "array" : typeof element;
            // TODO: Perf. Write a single byte (no need for the length prefix).
            writer.string(this.typeMarkers[type]);
            this.codersByType[type].encode(element, writer, context);
        }
    }
    decode(reader, context) {
        const typeMarker = reader.string();
        if (typeMarker === "Z") {
            return null;
        }
        else {
            const type = this.markerToTypes[typeMarker];
            return this.codersByType[type].decode(reader, context);
        }
    }
    toProto(pipelineContext) {
        return {
            spec: {
                urn: GeneralObjectCoder.URN,
                payload: new Uint8Array(),
            },
            componentCoderIds: [],
        };
    }
}
exports.GeneralObjectCoder = GeneralObjectCoder;
GeneralObjectCoder.URN = "beam:coder:genericobjectjs:v1";
globalRegistry().register(GeneralObjectCoder.URN, GeneralObjectCoder);
const _tct_flatten_destructured_imports_7 = __importStar(require("../serialization"));
var requireForSerialization = _tct_flatten_destructured_imports_7.requireForSerialization;
requireForSerialization("apache-beam/coders/js_coders", exports);
requireForSerialization("apache-beam/coders/js_coders", {
    NumberOrFloatCoder: NumberOrFloatCoder,
});
//# sourceMappingURL=js_coders.js.map