"use strict";
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
function registerLogicalType(logicalType) {
    logicalTypes.set(logicalType.urn, logicalType);
}
var _tct_transform_1, _tct_transform_2;
registerLogicalType.__closure = () => ({ logicalTypes });
function getLogicalFieldType(urn, nullable = true) {
    const info = logicalTypes.get(urn);
    return {
        nullable: nullable,
        typeInfo: {
            oneofKind: "logicalType",
            logicalType: LogicalType.create({
                urn,
                representation: info.reprType,
            }),
        },
    };
}
getLogicalFieldType.__closure = () => ({ logicalTypes, LogicalType });
Object.defineProperty(exports, "__esModule", { value: true });
exports.RowCoder = exports.registerLogicalType = void 0;
const _tct_flatten_destructured_imports_1 = __importStar(require("uuid"));
var uuid = _tct_flatten_destructured_imports_1;
const _tct_flatten_destructured_imports_2 = __importStar(require("../proto/beam_runner_api"));
var runnerApi = _tct_flatten_destructured_imports_2;
const _tct_flatten_destructured_imports_3 = __importStar(require("protobufjs"));
var Writer = _tct_flatten_destructured_imports_3.Writer;
var Reader = _tct_flatten_destructured_imports_3.Reader;
const _tct_flatten_destructured_imports_4 = __importStar(require("./coders"));
var Coder = _tct_flatten_destructured_imports_4.Coder;
var Context = _tct_flatten_destructured_imports_4.Context;
var ProtoContext = _tct_flatten_destructured_imports_4.ProtoContext;
var globalRegistry = _tct_flatten_destructured_imports_4.globalRegistry;
const _tct_flatten_destructured_imports_5 = __importStar(require("../proto/schema"));
var Schema = _tct_flatten_destructured_imports_5.Schema;
var Field = _tct_flatten_destructured_imports_5.Field;
var FieldType = _tct_flatten_destructured_imports_5.FieldType;
var AtomicType = _tct_flatten_destructured_imports_5.AtomicType;
var LogicalType = _tct_flatten_destructured_imports_5.LogicalType;
const _tct_flatten_destructured_imports_6 = __importStar(require("./standard_coders"));
var BoolCoder = _tct_flatten_destructured_imports_6.BoolCoder;
var BytesCoder = _tct_flatten_destructured_imports_6.BytesCoder;
var IterableCoder = _tct_flatten_destructured_imports_6.IterableCoder;
var NullableCoder = _tct_flatten_destructured_imports_6.NullableCoder;
var StrUtf8Coder = _tct_flatten_destructured_imports_6.StrUtf8Coder;
var VarIntCoder = _tct_flatten_destructured_imports_6.VarIntCoder;
const logicalTypes = new Map();
exports.registerLogicalType = registerLogicalType;
class TypePlaceholder {
    constructor(fieldType) {
        this.fieldType = fieldType;
    }
}
class LogicalTypePlaceholder extends TypePlaceholder {
    constructor(urn) {
        super(getLogicalFieldType(urn));
        this.urn = urn;
    }
}
const argsort = (x) => x
    .map((v, i) => [v, i])
    .sort()
    .map((y) => y[1]);
/**
 * A coder for encoding Objects as row objects with a given schema.
 *
 * This is particularly useful for cross-language interoperability,
 * and is more efficient than the general object encoding scheme as the
 * fields (and their types) are fixed and do not have to be encoded along
 * with each individual element.
 *
 * While RowCoders can be instantiated directly from a schema object,
 * there is also the convenience method `RowCoder.fromJSON()` method that
 * can infer a RowCoder from a prototypical example, e.g.
 *
 *```js
 * const my_row_coder = RowCoder.fromJSON({int_field: 0, str_field: ""});
 *```
 */
class RowCoder {
    constructor(rawSchema) {
        this.encodingPositionsAreTrivial = true;
        const schema = rawSchema instanceof Uint8Array
            ? Schema.fromBinary(rawSchema)
            : rawSchema;
        this.schema = schema;
        this.nFields = this.schema.fields.length;
        this.fieldNames = this.schema.fields.map((f) => f.name);
        this.fieldNullable = this.schema.fields.map((f) => f.type?.nullable);
        this.encodingPositions = this.schema.fields.map((_, i) => i);
        if (this.schema.encodingPositionsSet) {
            // Should never be duplicate encoding positions.
            let encPosx = schema.fields.map((f) => f.encodingPosition);
            if (encPosx.length !== this.encodingPositions.length) {
                throw new Error(`Schema with id ${this.schema.id} has encoding_positions_set=True, but not all fields have encoding_position set`);
            }
            // Checking if positions are in {0, ..., length-1}
            this.encodingPositionsAreTrivial = encPosx === this.encodingPositions;
            this.encodingPositions = encPosx;
            this.encodingPositionsArgsSorted = argsort(encPosx);
        }
        this.hasNullableFields = this.schema.fields.some((f) => f.type?.nullable);
        this.components = this.encodingPositions
            .map((i) => this.schema.fields[i])
            .map((f) => {
            if (f.type !== undefined) {
                return this.getNonNullCoderFromType(f.type);
            }
        });
    }
    addFieldOfType(obj, f, value) {
        if (f.type !== undefined) {
            let typeInfo = f.type?.typeInfo;
            switch (typeInfo.oneofKind) {
                case "atomicType":
                case "rowType":
                case "logicalType":
                    obj[f.name] = value;
                    break;
                case "arrayType":
                    obj[f.name] = value === undefined ? undefined : Array.from(value);
                    break;
                // case "iterableType":
                // case "mapType":
                default:
                    throw new Error(`Encountered a type that is not currently supported by RowCoder: ${JSON.stringify(f.type)}`);
            }
            return obj;
        }
    }
    static inferTypeFromJSON(obj, nullable = true) {
        if (obj instanceof TypePlaceholder) {
            return obj.fieldType;
        }
        let fieldType = {
            nullable: nullable,
            typeInfo: {
                oneofKind: undefined,
            },
        };
        switch (typeof obj) {
            case "string":
                fieldType.typeInfo = {
                    oneofKind: "atomicType",
                    atomicType: AtomicType.STRING,
                };
                break;
            case "boolean":
                fieldType.typeInfo = {
                    oneofKind: "atomicType",
                    atomicType: AtomicType.BOOLEAN,
                };
                break;
            case "number":
                if (Number.isInteger(obj)) {
                    fieldType.typeInfo = {
                        oneofKind: "atomicType",
                        atomicType: AtomicType.INT64,
                    };
                }
                else {
                    // TODO: Support float type.
                    // field.type!.typeInfo = {
                    //     oneofKind: "atomicType",
                    //     atomicType: AtomicType.FLOAT
                    // }
                }
                break;
            case "object":
                if (Array.isArray(obj)) {
                    fieldType.typeInfo = {
                        oneofKind: "arrayType",
                        arrayType: {
                            // TODO: Infer element type in a better way
                            elementType: RowCoder.inferTypeFromJSON(obj[0]),
                        },
                    };
                }
                else if (obj instanceof Uint8Array) {
                    fieldType.typeInfo = {
                        oneofKind: "atomicType",
                        atomicType: AtomicType.BYTES,
                    };
                }
                else if (obj.beamLogicalType) {
                    const logicalTypeInfo = logicalTypes.get(obj.beamLogicalType);
                    fieldType.typeInfo = {
                        oneofKind: "logicalType",
                        logicalType: {
                            urn: obj.beamLogicalType,
                            payload: new Uint8Array(),
                            representation: logicalTypeInfo?.reprType,
                        },
                    };
                }
                else {
                    fieldType.typeInfo = {
                        oneofKind: "rowType",
                        rowType: { schema: RowCoder.inferSchemaOfJSON(obj) },
                    };
                }
                break;
            default:
                fieldType.typeInfo = {
                    oneofKind: undefined,
                };
        }
        return fieldType;
    }
    static inferSchemaOfJSON(obj) {
        var _tct_transform_3;
        let fields = Object.entries(obj).map((_tct_transform_3 = (entry) => {
            return {
                name: entry[0],
                description: "",
                type: RowCoder.inferTypeFromJSON(entry[1]),
                id: 0,
                encodingPosition: 0,
                options: [],
            };
        }, _tct_transform_3.__closure = () => ({ RowCoder }), _tct_transform_3));
        return {
            id: uuid.v4(),
            fields: fields,
            options: [],
            encodingPositionsSet: false,
        };
    }
    getCoderFromType(t) {
        const nonNullCoder = this.getNonNullCoderFromType(t);
        if (t.nullable) {
            return new NullableCoder(nonNullCoder);
        }
        else {
            return nonNullCoder;
        }
    }
    getNonNullCoderFromType(t) {
        var _tct_transform_4, _tct_transform_5, _tct_transform_6;
        let typeInfo = t.typeInfo;
        switch (typeInfo.oneofKind) {
            case "atomicType":
                let atomicType = typeInfo.atomicType;
                switch (atomicType) {
                    case AtomicType.INT16:
                    case AtomicType.INT32:
                    case AtomicType.INT64:
                        return new VarIntCoder();
                    // case AtomicType.BYTE:
                    case AtomicType.BYTES:
                        return new BytesCoder();
                    // case AtomicType.FLOAT:
                    // case AtomicType.DOUBLE:
                    case AtomicType.STRING:
                        return new StrUtf8Coder();
                    case AtomicType.BOOLEAN:
                        return new BoolCoder();
                    default:
                        throw new Error(`Encountered an Atomic type that is not currently supported by RowCoder: ${atomicType}`);
                }
                break;
            case "arrayType":
                if (typeInfo.arrayType.elementType !== undefined) {
                    return new IterableCoder(this.getCoderFromType(typeInfo.arrayType.elementType));
                }
                else {
                    throw new Error("ElementType missing on ArrayType");
                }
            // case "iterableType":
            // case "mapType":
            case "rowType":
                if (typeInfo.rowType.schema !== undefined) {
                    return RowCoder.fromSchema(typeInfo.rowType.schema);
                }
                else {
                    throw new Error("Schema missing on RowType");
                }
                break;
            case "logicalType":
                const logicalTypeInfo = logicalTypes.get(typeInfo.logicalType.urn);
                if (logicalTypeInfo !== undefined) {
                    const reprCoder = this.getCoderFromType(typeInfo.logicalType.representation);
                    return {
                        encode: (_tct_transform_4 = (element, writer, context) => reprCoder.encode(logicalTypeInfo.toRepr(element), writer, context), _tct_transform_4.__closure = () => ({ reprCoder, logicalTypeInfo }), _tct_transform_4),
                        decode: (_tct_transform_5 = (reader, context) => logicalTypeInfo.fromRepr(reprCoder.decode(reader, context)), _tct_transform_5.__closure = () => ({ logicalTypeInfo, reprCoder }), _tct_transform_5),
                        toProto: (_tct_transform_6 = (pipelineContext) => {
                            throw new Error("Ephemeral coder.");
                        }, _tct_transform_6.__closure = () => ({ Error }), _tct_transform_6),
                    };
                }
                else {
                    throw new Error(`Unknown logical type: ${typeInfo.logicalType.urn}`);
                }
                break;
            default:
                throw new Error(`Encountered a type that is not currently supported by RowCoder: ${JSON.stringify(t)}`);
        }
    }
    static fromSchema(schema) {
        return new RowCoder(schema);
    }
    static fromJSON(obj) {
        return new RowCoder(RowCoder.inferSchemaOfJSON(obj));
    }
    encode(element, writer, context) {
        var _tct_transform_7, _tct_transform_8, _tct_transform_9;
        // The number of attributes in the schema, encoded with
        // beam:coder:varint:v1. This makes it possible to detect certain
        // allowed schema changes (appending or removing columns) in
        // long-running streaming pipelines.
        writer.int32(this.nFields);
        // A byte array representing a packed bitset indicating null fields (a
        //     1 indicating a null) encoded with beam:coder:bytes:v1. The unused
        //     bits in the last byte must be set to 0. If there are no nulls an
        //     empty byte array is encoded.
        //     The two-byte bitset (not including the lenghth-prefix) for the row
        //     [NULL, 0, 0, 0, NULL, 0, 0, NULL, 0, NULL] would be
        //     [0b10010001, 0b00000010]
        let attrs = this.fieldNames.map((_tct_transform_7 = (name) => element[name], _tct_transform_7.__closure = () => ({ element }), _tct_transform_7));
        let bytesCoder = new BytesCoder();
        let nullFields = [];
        if (this.hasNullableFields) {
            if (attrs.some((attr) => attr === null || attr === undefined)) {
                let running = { value: undefined };
                running.value = 0;
                attrs.forEach((_tct_transform_8 = (attr, i) => {
                    if (i && i % 8 === 0) {
                        nullFields.push(running.value);
                        running.value = 0;
                    }
                    running.value = running.value | (attr === null || attr === undefined ? 1 : 0) << i % 8;
                }, _tct_transform_8.__closure = () => ({ nullFields, running }), _tct_transform_8));
                nullFields.push(running.value);
            }
        }
        writer.bytes(new Uint8Array(nullFields));
        // An encoding for each non-null field, concatenated together.
        let positions = this.encodingPositionsAreTrivial
            ? this.encodingPositions
            : this.encodingPositionsArgsSorted;
        positions.forEach((_tct_transform_9 = (i) => {
            let attr = attrs[i];
            if (attr === null || attr === undefined) {
                if (!this.fieldNullable[i]) {
                    throw new Error(`Attempted to encode null for non-nullable field \"${this.schema.fields[i].name}\".`);
                }
            }
            else {
                this.components[i].encode(attr, writer, Context.needsDelimiters);
            }
        }, _tct_transform_9.__closure = () => ({ attrs, Error, writer, Context }), _tct_transform_9));
    }
    decode(reader, context) {
        var _tct_transform_10, _tct_transform_11, _tct_transform_12;
        let nFields = reader.int32();
        // Addressing Null values
        let nulls, hasNulls = { value: undefined };
        hasNulls.value = false;
        // Addressing Null values
        let nullMaskBytes = reader.int32(), nullMask = reader.buf.slice(reader.pos, reader.pos + nullMaskBytes);
        reader.pos += nullMaskBytes;
        if (nullMask.length > 0) {
            hasNulls.value = true;
            let running = { value: undefined };
            running.value = 0;
            nulls = Array(nFields)
                .fill(0)
                .map((_tct_transform_10 = (_, i) => {
                if (i % 8 === 0) {
                    let chunk = Math.floor(i / 8);
                    running.value = chunk >= nullMask.length ? 0 : nullMask[chunk];
                }
                return (running.value >> i % 8) & 0x01;
            }, _tct_transform_10.__closure = () => ({ Math, running, nullMask }), _tct_transform_10));
        }
        // Note that if this coder's schema has *fewer* attributes than the encoded
        // value, we just need to ignore the additional values, which will occur
        // here because we only decode as many values as we have coders for.
        let positions = this.encodingPositionsAreTrivial
            ? this.encodingPositions
            : this.encodingPositionsArgsSorted, sortedComponents = positions
            .slice(0, Math.min(this.nFields, nFields))
            .map((_tct_transform_11 = (i) => {
            if (hasNulls.value && nulls[i]) {
                return undefined;
            }
            else {
                return this.components[i].decode(reader, Context.needsDelimiters);
            }
        }, _tct_transform_11.__closure = () => ({ hasNulls, nulls, reader, Context }), _tct_transform_11));
        // If this coder's schema has more attributes than the encoded value, then
        // the schema must have changed. Populate the unencoded fields with
        // undefined.
        while (sortedComponents.length < this.nFields) {
            sortedComponents.push(undefined);
        }
        let obj = { value: undefined };
        obj.value = {};
        positions.forEach((_tct_transform_12 = (i) => {
            obj.value = this.addFieldOfType(obj.value, this.schema.fields[i], sortedComponents[i]);
        }, _tct_transform_12.__closure = () => ({ obj, sortedComponents }), _tct_transform_12));
        return obj.value;
    }
    toProto(pipelineContext) {
        return {
            spec: {
                urn: RowCoder.URN,
                payload: Schema.toBinary(this.schema),
            },
            componentCoderIds: [],
        };
    }
}
exports.RowCoder = RowCoder;
RowCoder.URN = "beam:coder:row:v1";
globalRegistry().register(RowCoder.URN, RowCoder);
registerLogicalType({
    urn: "beam:logical_type:schema:v1",
    reprType: RowCoder.inferTypeFromJSON(new Uint8Array(), false),
    toRepr: (_tct_transform_1 = (schema) => Schema.toBinary(schema), _tct_transform_1.__closure = () => ({ Schema }), _tct_transform_1),
    fromRepr: (_tct_transform_2 = (serialized) => Schema.fromBinary(serialized), _tct_transform_2.__closure = () => ({ Schema }), _tct_transform_2),
});
//# sourceMappingURL=row_coder.js.map