import * as runnerApi from "../proto/beam_runner_api";
import { Reader, Writer } from "protobufjs";
import { Coder, Context, ProtoContext } from "./coders";
import { IntervalWindow } from "../values";
export * from "./required_coders";
/**
 * @fileoverview Defines all of the Apache Beam standard coders.
 *
 * Beyond required coders, standard coders provide an efficient way to encode
 * data for communication between the runner and various Beam workers for
 * types that commonly cross process boundaries. Though none of these coders
 * is strictly necessary, if encodings are given for these types it is highly
 * advised to use these definitions that are interoperable with runners and
 * other SDKs.
 *
 * For the schema-aware transform RowCoder, which is a coder for rows of data
 * with a predetermined schema, it is also advised.
 *
 * The formal specifications for these coders can be found in
 * model/pipeline/src/main/proto/beam_runner_api.proto
 */
export declare class StrUtf8Coder implements Coder<string> {
    static URN: string;
    type: string;
    encoder: TextEncoder;
    decoder: TextDecoder;
    encode(element: string, writer: Writer, context: Context): void;
    decode(reader: Reader, context: Context): string;
    toProto(): runnerApi.Coder;
}
export declare class VarIntCoder implements Coder<number> {
    static URN: string;
    static INSTANCE: VarIntCoder;
    type: string;
    encode(element: number, writer: Writer): void;
    decode(reader: Reader): number;
    toProto(): runnerApi.Coder;
}
export declare class DoubleCoder implements Coder<number> {
    static URN: string;
    encode(element: number, writer: Writer): void;
    decode(reader: Reader): number;
    toProto(): runnerApi.Coder;
}
export declare class BoolCoder implements Coder<boolean> {
    static URN: string;
    type: string;
    encode(element: boolean, writer: Writer): void;
    decode(reader: Reader): boolean;
    toProto(): runnerApi.Coder;
}
export declare class NullableCoder<T> implements Coder<T | undefined> {
    static URN: string;
    type: string;
    elementCoder: Coder<T>;
    constructor(elementCoder: Coder<T>);
    encode(element: T | undefined, writer: Writer, context: Context): void;
    decode(reader: Reader, context: Context): T | undefined;
    toProto(pipelineContext: ProtoContext): runnerApi.Coder;
}
export declare class IntervalWindowCoder implements Coder<IntervalWindow> {
    static URN: string;
    static INSTANCE: IntervalWindowCoder;
    encode(value: IntervalWindow, writer: Writer, context: Context): void;
    decode(reader: Reader, context: Context): IntervalWindow;
    toProto(): runnerApi.Coder;
}
