import { ServiceType } from "@protobuf-ts/runtime-rpc";
import type { BinaryWriteOptions } from "@protobuf-ts/runtime";
import type { IBinaryWriter } from "@protobuf-ts/runtime";
import type { BinaryReadOptions } from "@protobuf-ts/runtime";
import type { IBinaryReader } from "@protobuf-ts/runtime";
import type { PartialMessage } from "@protobuf-ts/runtime";
import { MessageType } from "@protobuf-ts/runtime";
import { ArtifactInformation } from "../../pipeline/v1/beam_runner_api";
/**
 * A request for artifact resolution.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.ResolveArtifactsRequest
 */
export interface ResolveArtifactsRequest {
    /**
     * An (ordered) set of artifacts to (jointly) resolve.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.ArtifactInformation artifacts = 1;
     */
    artifacts: ArtifactInformation[];
    /**
     * A set of artifact type urns that are understood by the requester.
     * An attempt should be made to resolve the artifacts in terms of these URNs,
     * but other URNs may be used as well with the understanding that they must
     * be fetch-able as bytes via GetArtifact.
     *
     * @generated from protobuf field: repeated string preferred_urns = 2;
     */
    preferredUrns: string[];
}
/**
 * A response for artifact resolution.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.ResolveArtifactsResponse
 */
export interface ResolveArtifactsResponse {
    /**
     * A full (ordered) set of replacements for the set of requested artifacts,
     * preferably in terms of the requested type URNs.  If there is no better
     * resolution, the original list is returned.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.ArtifactInformation replacements = 1;
     */
    replacements: ArtifactInformation[];
}
/**
 * A request to get an artifact.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.GetArtifactRequest
 */
export interface GetArtifactRequest {
    /**
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.ArtifactInformation artifact = 1;
     */
    artifact?: ArtifactInformation;
}
/**
 * Part of a response to getting an artifact.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.GetArtifactResponse
 */
export interface GetArtifactResponse {
    /**
     * @generated from protobuf field: bytes data = 1;
     */
    data: Uint8Array;
}
/**
 * Wraps an ArtifactRetrievalService request for use in ReverseArtifactRetrievalService.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.ArtifactRequestWrapper
 */
export interface ArtifactRequestWrapper {
    /**
     * @generated from protobuf oneof: request
     */
    request: {
        oneofKind: "resolveArtifact";
        /**
         * @generated from protobuf field: org.apache.beam.model.job_management.v1.ResolveArtifactsRequest resolve_artifact = 1000;
         */
        resolveArtifact: ResolveArtifactsRequest;
    } | {
        oneofKind: "getArtifact";
        /**
         * @generated from protobuf field: org.apache.beam.model.job_management.v1.GetArtifactRequest get_artifact = 1001;
         */
        getArtifact: GetArtifactRequest;
    } | {
        oneofKind: undefined;
    };
}
/**
 * Wraps an ArtifactRetrievalService response for use in ReverseArtifactRetrievalService.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.ArtifactResponseWrapper
 */
export interface ArtifactResponseWrapper {
    /**
     * A token indicating which job these artifacts are being staged for.
     *
     * @generated from protobuf field: string staging_token = 1;
     */
    stagingToken: string;
    /**
     * Whether this is the last response for this request (for those responses that
     * would typically be terminated by the end of the response stream.)
     *
     * @generated from protobuf field: bool is_last = 2;
     */
    isLast: boolean;
    /**
     * @generated from protobuf oneof: response
     */
    response: {
        oneofKind: "resolveArtifactResponse";
        /**
         * @generated from protobuf field: org.apache.beam.model.job_management.v1.ResolveArtifactsResponse resolve_artifact_response = 1000;
         */
        resolveArtifactResponse: ResolveArtifactsResponse;
    } | {
        oneofKind: "getArtifactResponse";
        /**
         * @generated from protobuf field: org.apache.beam.model.job_management.v1.GetArtifactResponse get_artifact_response = 1001;
         */
        getArtifactResponse: GetArtifactResponse;
    } | {
        oneofKind: undefined;
    };
}
/**
 * An artifact identifier and associated metadata.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.ArtifactMetadata
 */
export interface ArtifactMetadata {
    /**
     * (Required) The name of the artifact.
     *
     * @generated from protobuf field: string name = 1;
     */
    name: string;
    /**
     * (Optional) The Unix-like permissions of the artifact
     *
     * @generated from protobuf field: uint32 permissions = 2;
     */
    permissions: number;
    /**
     * (Optional) The hex-encoded sha256 checksum of the artifact. Used, among other things, by
     * harness boot code to validate the integrity of the artifact.
     *
     * @generated from protobuf field: string sha256 = 4;
     */
    sha256: string;
}
/**
 * A collection of artifacts.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.Manifest
 */
export interface Manifest {
    /**
     * @generated from protobuf field: repeated org.apache.beam.model.job_management.v1.ArtifactMetadata artifact = 1;
     */
    artifact: ArtifactMetadata[];
}
/**
 * A manifest with location information.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.ProxyManifest
 */
export interface ProxyManifest {
    /**
     * @generated from protobuf field: org.apache.beam.model.job_management.v1.Manifest manifest = 1;
     */
    manifest?: Manifest;
    /**
     * @generated from protobuf field: repeated org.apache.beam.model.job_management.v1.ProxyManifest.Location location = 2;
     */
    location: ProxyManifest_Location[];
}
/**
 * @generated from protobuf message org.apache.beam.model.job_management.v1.ProxyManifest.Location
 */
export interface ProxyManifest_Location {
    /**
     * @generated from protobuf field: string name = 1;
     */
    name: string;
    /**
     * @generated from protobuf field: string uri = 2;
     */
    uri: string;
}
/**
 * A request to get the manifest of a Job.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.GetManifestRequest
 */
export interface GetManifestRequest {
    /**
     * (Required) An opaque token representing the entirety of the staged artifacts.
     * Returned in CommitManifestResponse.
     *
     * @generated from protobuf field: string retrieval_token = 1;
     */
    retrievalToken: string;
}
/**
 * A response containing a job manifest.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.GetManifestResponse
 */
export interface GetManifestResponse {
    /**
     * @generated from protobuf field: org.apache.beam.model.job_management.v1.Manifest manifest = 1;
     */
    manifest?: Manifest;
}
/**
 * A request to get an artifact. The artifact must be present in the manifest for the job.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.LegacyGetArtifactRequest
 */
export interface LegacyGetArtifactRequest {
    /**
     * (Required) The name of the artifact to retrieve.
     *
     * @generated from protobuf field: string name = 1;
     */
    name: string;
    /**
     * (Required) An opaque token representing the entirety of the staged artifacts.
     * Returned in CommitManifestResponse.
     *
     * @generated from protobuf field: string retrieval_token = 2;
     */
    retrievalToken: string;
}
/**
 * Part of an artifact.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.ArtifactChunk
 */
export interface ArtifactChunk {
    /**
     * @generated from protobuf field: bytes data = 1;
     */
    data: Uint8Array;
}
/**
 * @generated from protobuf message org.apache.beam.model.job_management.v1.PutArtifactMetadata
 */
export interface PutArtifactMetadata {
    /**
     * (Required) A token for artifact staging session. This token can be obtained
     * from PrepareJob request in JobService
     *
     * @generated from protobuf field: string staging_session_token = 1;
     */
    stagingSessionToken: string;
    /**
     * (Required) The Artifact metadata.
     *
     * @generated from protobuf field: org.apache.beam.model.job_management.v1.ArtifactMetadata metadata = 2;
     */
    metadata?: ArtifactMetadata;
}
/**
 * A request to stage an artifact.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.PutArtifactRequest
 */
export interface PutArtifactRequest {
    /**
     * @generated from protobuf oneof: content
     */
    content: {
        oneofKind: "metadata";
        /**
         * The first message in a PutArtifact call must contain this field.
         *
         * @generated from protobuf field: org.apache.beam.model.job_management.v1.PutArtifactMetadata metadata = 1;
         */
        metadata: PutArtifactMetadata;
    } | {
        oneofKind: "data";
        /**
         * A chunk of the artifact. All messages after the first in a PutArtifact call must contain a
         * chunk.
         *
         * @generated from protobuf field: org.apache.beam.model.job_management.v1.ArtifactChunk data = 2;
         */
        data: ArtifactChunk;
    } | {
        oneofKind: undefined;
    };
}
/**
 * @generated from protobuf message org.apache.beam.model.job_management.v1.PutArtifactResponse
 */
export interface PutArtifactResponse {
}
/**
 * A request to commit the manifest for a Job. All artifacts must have been successfully uploaded
 * before this call is made.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.CommitManifestRequest
 */
export interface CommitManifestRequest {
    /**
     * (Required) The manifest to commit.
     *
     * @generated from protobuf field: org.apache.beam.model.job_management.v1.Manifest manifest = 1;
     */
    manifest?: Manifest;
    /**
     * (Required) A token for artifact staging session. This token can be obtained
     * from PrepareJob request in JobService
     *
     * @generated from protobuf field: string staging_session_token = 2;
     */
    stagingSessionToken: string;
}
/**
 * The result of committing a manifest.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.CommitManifestResponse
 */
export interface CommitManifestResponse {
    /**
     * (Required) An opaque token representing the entirety of the staged artifacts.
     * This can be used to retrieve the manifest and artifacts from an associated
     * LegacyArtifactRetrievalService.
     *
     * @generated from protobuf field: string retrieval_token = 1;
     */
    retrievalToken: string;
}
/**
 * @generated from protobuf enum org.apache.beam.model.job_management.v1.CommitManifestResponse.Constants
 */
export declare enum CommitManifestResponse_Constants {
    /**
     * Token indicating that no artifacts were staged and therefore no retrieval attempt is necessary.
     *
     * @generated from protobuf enum value: NO_ARTIFACTS_STAGED_TOKEN = 0;
     */
    NO_ARTIFACTS_STAGED_TOKEN = 0
}
declare class ResolveArtifactsRequest$Type extends MessageType<ResolveArtifactsRequest> {
    constructor();
    create(value?: PartialMessage<ResolveArtifactsRequest>): ResolveArtifactsRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ResolveArtifactsRequest): ResolveArtifactsRequest;
    internalBinaryWrite(message: ResolveArtifactsRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.ResolveArtifactsRequest
 */
export declare const ResolveArtifactsRequest: ResolveArtifactsRequest$Type;
declare class ResolveArtifactsResponse$Type extends MessageType<ResolveArtifactsResponse> {
    constructor();
    create(value?: PartialMessage<ResolveArtifactsResponse>): ResolveArtifactsResponse;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ResolveArtifactsResponse): ResolveArtifactsResponse;
    internalBinaryWrite(message: ResolveArtifactsResponse, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.ResolveArtifactsResponse
 */
export declare const ResolveArtifactsResponse: ResolveArtifactsResponse$Type;
declare class GetArtifactRequest$Type extends MessageType<GetArtifactRequest> {
    constructor();
    create(value?: PartialMessage<GetArtifactRequest>): GetArtifactRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: GetArtifactRequest): GetArtifactRequest;
    internalBinaryWrite(message: GetArtifactRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.GetArtifactRequest
 */
export declare const GetArtifactRequest: GetArtifactRequest$Type;
declare class GetArtifactResponse$Type extends MessageType<GetArtifactResponse> {
    constructor();
    create(value?: PartialMessage<GetArtifactResponse>): GetArtifactResponse;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: GetArtifactResponse): GetArtifactResponse;
    internalBinaryWrite(message: GetArtifactResponse, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.GetArtifactResponse
 */
export declare const GetArtifactResponse: GetArtifactResponse$Type;
declare class ArtifactRequestWrapper$Type extends MessageType<ArtifactRequestWrapper> {
    constructor();
    create(value?: PartialMessage<ArtifactRequestWrapper>): ArtifactRequestWrapper;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ArtifactRequestWrapper): ArtifactRequestWrapper;
    internalBinaryWrite(message: ArtifactRequestWrapper, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.ArtifactRequestWrapper
 */
export declare const ArtifactRequestWrapper: ArtifactRequestWrapper$Type;
declare class ArtifactResponseWrapper$Type extends MessageType<ArtifactResponseWrapper> {
    constructor();
    create(value?: PartialMessage<ArtifactResponseWrapper>): ArtifactResponseWrapper;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ArtifactResponseWrapper): ArtifactResponseWrapper;
    internalBinaryWrite(message: ArtifactResponseWrapper, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.ArtifactResponseWrapper
 */
export declare const ArtifactResponseWrapper: ArtifactResponseWrapper$Type;
declare class ArtifactMetadata$Type extends MessageType<ArtifactMetadata> {
    constructor();
    create(value?: PartialMessage<ArtifactMetadata>): ArtifactMetadata;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ArtifactMetadata): ArtifactMetadata;
    internalBinaryWrite(message: ArtifactMetadata, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.ArtifactMetadata
 */
export declare const ArtifactMetadata: ArtifactMetadata$Type;
declare class Manifest$Type extends MessageType<Manifest> {
    constructor();
    create(value?: PartialMessage<Manifest>): Manifest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: Manifest): Manifest;
    internalBinaryWrite(message: Manifest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.Manifest
 */
export declare const Manifest: Manifest$Type;
declare class ProxyManifest$Type extends MessageType<ProxyManifest> {
    constructor();
    create(value?: PartialMessage<ProxyManifest>): ProxyManifest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ProxyManifest): ProxyManifest;
    internalBinaryWrite(message: ProxyManifest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.ProxyManifest
 */
export declare const ProxyManifest: ProxyManifest$Type;
declare class ProxyManifest_Location$Type extends MessageType<ProxyManifest_Location> {
    constructor();
    create(value?: PartialMessage<ProxyManifest_Location>): ProxyManifest_Location;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ProxyManifest_Location): ProxyManifest_Location;
    internalBinaryWrite(message: ProxyManifest_Location, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.ProxyManifest.Location
 */
export declare const ProxyManifest_Location: ProxyManifest_Location$Type;
declare class GetManifestRequest$Type extends MessageType<GetManifestRequest> {
    constructor();
    create(value?: PartialMessage<GetManifestRequest>): GetManifestRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: GetManifestRequest): GetManifestRequest;
    internalBinaryWrite(message: GetManifestRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.GetManifestRequest
 */
export declare const GetManifestRequest: GetManifestRequest$Type;
declare class GetManifestResponse$Type extends MessageType<GetManifestResponse> {
    constructor();
    create(value?: PartialMessage<GetManifestResponse>): GetManifestResponse;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: GetManifestResponse): GetManifestResponse;
    internalBinaryWrite(message: GetManifestResponse, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.GetManifestResponse
 */
export declare const GetManifestResponse: GetManifestResponse$Type;
declare class LegacyGetArtifactRequest$Type extends MessageType<LegacyGetArtifactRequest> {
    constructor();
    create(value?: PartialMessage<LegacyGetArtifactRequest>): LegacyGetArtifactRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: LegacyGetArtifactRequest): LegacyGetArtifactRequest;
    internalBinaryWrite(message: LegacyGetArtifactRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.LegacyGetArtifactRequest
 */
export declare const LegacyGetArtifactRequest: LegacyGetArtifactRequest$Type;
declare class ArtifactChunk$Type extends MessageType<ArtifactChunk> {
    constructor();
    create(value?: PartialMessage<ArtifactChunk>): ArtifactChunk;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: ArtifactChunk): ArtifactChunk;
    internalBinaryWrite(message: ArtifactChunk, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.ArtifactChunk
 */
export declare const ArtifactChunk: ArtifactChunk$Type;
declare class PutArtifactMetadata$Type extends MessageType<PutArtifactMetadata> {
    constructor();
    create(value?: PartialMessage<PutArtifactMetadata>): PutArtifactMetadata;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: PutArtifactMetadata): PutArtifactMetadata;
    internalBinaryWrite(message: PutArtifactMetadata, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.PutArtifactMetadata
 */
export declare const PutArtifactMetadata: PutArtifactMetadata$Type;
declare class PutArtifactRequest$Type extends MessageType<PutArtifactRequest> {
    constructor();
    create(value?: PartialMessage<PutArtifactRequest>): PutArtifactRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: PutArtifactRequest): PutArtifactRequest;
    internalBinaryWrite(message: PutArtifactRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.PutArtifactRequest
 */
export declare const PutArtifactRequest: PutArtifactRequest$Type;
declare class PutArtifactResponse$Type extends MessageType<PutArtifactResponse> {
    constructor();
    create(value?: PartialMessage<PutArtifactResponse>): PutArtifactResponse;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: PutArtifactResponse): PutArtifactResponse;
    internalBinaryWrite(message: PutArtifactResponse, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.PutArtifactResponse
 */
export declare const PutArtifactResponse: PutArtifactResponse$Type;
declare class CommitManifestRequest$Type extends MessageType<CommitManifestRequest> {
    constructor();
    create(value?: PartialMessage<CommitManifestRequest>): CommitManifestRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: CommitManifestRequest): CommitManifestRequest;
    internalBinaryWrite(message: CommitManifestRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.CommitManifestRequest
 */
export declare const CommitManifestRequest: CommitManifestRequest$Type;
declare class CommitManifestResponse$Type extends MessageType<CommitManifestResponse> {
    constructor();
    create(value?: PartialMessage<CommitManifestResponse>): CommitManifestResponse;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: CommitManifestResponse): CommitManifestResponse;
    internalBinaryWrite(message: CommitManifestResponse, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.CommitManifestResponse
 */
export declare const CommitManifestResponse: CommitManifestResponse$Type;
/**
 * @generated ServiceType for protobuf service org.apache.beam.model.job_management.v1.ArtifactRetrievalService
 */
export declare const ArtifactRetrievalService: ServiceType;
/**
 * @generated ServiceType for protobuf service org.apache.beam.model.job_management.v1.ArtifactStagingService
 */
export declare const ArtifactStagingService: ServiceType;
/**
 * @generated ServiceType for protobuf service org.apache.beam.model.job_management.v1.LegacyArtifactStagingService
 */
export declare const LegacyArtifactStagingService: ServiceType;
/**
 * @generated ServiceType for protobuf service org.apache.beam.model.job_management.v1.LegacyArtifactRetrievalService
 */
export declare const LegacyArtifactRetrievalService: ServiceType;
export {};
