import { ServiceType } from "@protobuf-ts/runtime-rpc";
import type { BinaryWriteOptions } from "@protobuf-ts/runtime";
import type { IBinaryWriter } from "@protobuf-ts/runtime";
import type { BinaryReadOptions } from "@protobuf-ts/runtime";
import type { IBinaryReader } from "@protobuf-ts/runtime";
import type { PartialMessage } from "@protobuf-ts/runtime";
import { MessageType } from "@protobuf-ts/runtime";
import { MonitoringInfo } from "../../pipeline/v1/metrics";
import { Timestamp } from "../../../../../../google/protobuf/timestamp";
import { ApiServiceDescriptor } from "../../pipeline/v1/endpoints";
import { Struct } from "../../../../../../google/protobuf/struct";
import { Pipeline } from "../../pipeline/v1/beam_runner_api";
/**
 * Prepare is a synchronous request that returns a preparationId back
 * Throws error GRPC_STATUS_UNAVAILABLE if server is down
 * Throws error ALREADY_EXISTS if the jobName is reused. Runners are permitted to deduplicate based on the name of the job.
 * Throws error UNKNOWN for all other issues
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.PrepareJobRequest
 */
export interface PrepareJobRequest {
    /**
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Pipeline pipeline = 1;
     */
    pipeline?: Pipeline;
    /**
     * @generated from protobuf field: google.protobuf.Struct pipeline_options = 2;
     */
    pipelineOptions?: Struct;
    /**
     * @generated from protobuf field: string job_name = 3;
     */
    jobName: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.job_management.v1.PrepareJobResponse
 */
export interface PrepareJobResponse {
    /**
     * (required) The ID used to associate calls made while preparing the job. preparationId is used
     * to run the job.
     *
     * @generated from protobuf field: string preparation_id = 1;
     */
    preparationId: string;
    /**
     * An endpoint which exposes the Beam Artifact Staging API. Artifacts used by the job should be
     * staged to this endpoint, and will be available during job execution.
     *
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.ApiServiceDescriptor artifact_staging_endpoint = 2;
     */
    artifactStagingEndpoint?: ApiServiceDescriptor;
    /**
     * (required) Token for the artifact staging. This token also represent an artifact
     * staging session with the artifact staging service.
     *
     * @generated from protobuf field: string staging_session_token = 3;
     */
    stagingSessionToken: string;
}
/**
 * Run is a synchronous request that returns a jobId back.
 * Throws error GRPC_STATUS_UNAVAILABLE if server is down
 * Throws error NOT_FOUND if the preparation ID does not exist
 * Throws error UNKNOWN for all other issues
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.RunJobRequest
 */
export interface RunJobRequest {
    /**
     * (required) The ID provided by an earlier call to prepare. Runs the job. All prerequisite tasks
     * must have been completed.
     *
     * @generated from protobuf field: string preparation_id = 1;
     */
    preparationId: string;
    /**
     * (optional) If any artifacts have been staged for this job, contains the retrieval_token returned
     * from the CommitManifestResponse.
     *
     * @generated from protobuf field: string retrieval_token = 2;
     */
    retrievalToken: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.job_management.v1.RunJobResponse
 */
export interface RunJobResponse {
    /**
     * @generated from protobuf field: string job_id = 1;
     */
    jobId: string;
}
/**
 * Cancel is a synchronus request that returns a job state back
 * Throws error GRPC_STATUS_UNAVAILABLE if server is down
 * Throws error NOT_FOUND if the jobId is not found
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.CancelJobRequest
 */
export interface CancelJobRequest {
    /**
     * @generated from protobuf field: string job_id = 1;
     */
    jobId: string;
}
/**
 * Valid responses include any terminal state or CANCELLING
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.CancelJobResponse
 */
export interface CancelJobResponse {
    /**
     * @generated from protobuf field: org.apache.beam.model.job_management.v1.JobState.Enum state = 1;
     */
    state: JobState_Enum;
}
/**
 * A subset of info provided by ProvisionApi.ProvisionInfo
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.JobInfo
 */
export interface JobInfo {
    /**
     * @generated from protobuf field: string job_id = 1;
     */
    jobId: string;
    /**
     * @generated from protobuf field: string job_name = 2;
     */
    jobName: string;
    /**
     * @generated from protobuf field: google.protobuf.Struct pipeline_options = 3;
     */
    pipelineOptions?: Struct;
    /**
     * @generated from protobuf field: org.apache.beam.model.job_management.v1.JobState.Enum state = 4;
     */
    state: JobState_Enum;
}
/**
 * GetJobs is a synchronus request that returns a list of invoked jobs back
 * Throws error GRPC_STATUS_UNAVAILABLE if server is down
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.GetJobsRequest
 */
export interface GetJobsRequest {
}
/**
 * @generated from protobuf message org.apache.beam.model.job_management.v1.GetJobsResponse
 */
export interface GetJobsResponse {
    /**
     * @generated from protobuf field: repeated org.apache.beam.model.job_management.v1.JobInfo job_info = 1;
     */
    jobInfo: JobInfo[];
}
/**
 * GetState is a synchronus request that returns a job state back
 * Throws error GRPC_STATUS_UNAVAILABLE if server is down
 * Throws error NOT_FOUND if the jobId is not found
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.GetJobStateRequest
 */
export interface GetJobStateRequest {
    /**
     * @generated from protobuf field: string job_id = 1;
     */
    jobId: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.job_management.v1.JobStateEvent
 */
export interface JobStateEvent {
    /**
     * @generated from protobuf field: org.apache.beam.model.job_management.v1.JobState.Enum state = 1;
     */
    state: JobState_Enum;
    /**
     * @generated from protobuf field: google.protobuf.Timestamp timestamp = 2;
     */
    timestamp?: Timestamp;
}
/**
 * GetPipeline is a synchronus request that returns a pipeline back
 * Throws error GRPC_STATUS_UNAVAILABLE if server is down
 * Throws error NOT_FOUND if the jobId is not found
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.GetJobPipelineRequest
 */
export interface GetJobPipelineRequest {
    /**
     * @generated from protobuf field: string job_id = 1;
     */
    jobId: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.job_management.v1.GetJobPipelineResponse
 */
export interface GetJobPipelineResponse {
    /**
     * @generated from protobuf field: org.apache.beam.model.pipeline.v1.Pipeline pipeline = 1;
     */
    pipeline?: Pipeline;
}
/**
 * GetJobMessages is a streaming api for streaming job messages from the service
 * One request will connect you to the job and you'll get a stream of job state
 * and job messages back; one is used for logging and the other for detecting
 * the job ended.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.JobMessagesRequest
 */
export interface JobMessagesRequest {
    /**
     * @generated from protobuf field: string job_id = 1;
     */
    jobId: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.job_management.v1.JobMessage
 */
export interface JobMessage {
    /**
     * @generated from protobuf field: string message_id = 1;
     */
    messageId: string;
    /**
     * @generated from protobuf field: string time = 2;
     */
    time: string;
    /**
     * @generated from protobuf field: org.apache.beam.model.job_management.v1.JobMessage.MessageImportance importance = 3;
     */
    importance: JobMessage_MessageImportance;
    /**
     * @generated from protobuf field: string message_text = 4;
     */
    messageText: string;
}
/**
 * @generated from protobuf enum org.apache.beam.model.job_management.v1.JobMessage.MessageImportance
 */
export declare enum JobMessage_MessageImportance {
    /**
     * @generated from protobuf enum value: MESSAGE_IMPORTANCE_UNSPECIFIED = 0;
     */
    MESSAGE_IMPORTANCE_UNSPECIFIED = 0,
    /**
     * @generated from protobuf enum value: JOB_MESSAGE_DEBUG = 1;
     */
    JOB_MESSAGE_DEBUG = 1,
    /**
     * @generated from protobuf enum value: JOB_MESSAGE_DETAILED = 2;
     */
    JOB_MESSAGE_DETAILED = 2,
    /**
     * @generated from protobuf enum value: JOB_MESSAGE_BASIC = 3;
     */
    JOB_MESSAGE_BASIC = 3,
    /**
     * @generated from protobuf enum value: JOB_MESSAGE_WARNING = 4;
     */
    JOB_MESSAGE_WARNING = 4,
    /**
     * @generated from protobuf enum value: JOB_MESSAGE_ERROR = 5;
     */
    JOB_MESSAGE_ERROR = 5
}
/**
 * @generated from protobuf message org.apache.beam.model.job_management.v1.JobMessagesResponse
 */
export interface JobMessagesResponse {
    /**
     * @generated from protobuf oneof: response
     */
    response: {
        oneofKind: "messageResponse";
        /**
         * @generated from protobuf field: org.apache.beam.model.job_management.v1.JobMessage message_response = 1;
         */
        messageResponse: JobMessage;
    } | {
        oneofKind: "stateResponse";
        /**
         * @generated from protobuf field: org.apache.beam.model.job_management.v1.JobStateEvent state_response = 2;
         */
        stateResponse: JobStateEvent;
    } | {
        oneofKind: undefined;
    };
}
/**
 * Enumeration of all JobStates
 *
 * The state transition diagram is:
 *   STOPPED -> STARTING -> RUNNING -> DONE
 *                                  \> FAILED
 *                                  \> CANCELLING -> CANCELLED
 *                                  \> UPDATING -> UPDATED
 *                                  \> DRAINING -> DRAINED
 *
 * Transitions are optional such that a job may go from STOPPED to RUNNING
 * without needing to pass through STARTING.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.JobState
 */
export interface JobState {
}
/**
 * @generated from protobuf enum org.apache.beam.model.job_management.v1.JobState.Enum
 */
export declare enum JobState_Enum {
    /**
     * The job state reported by a runner cannot be interpreted by the SDK.
     *
     * @generated from protobuf enum value: UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * The job has not yet started.
     *
     * @generated from protobuf enum value: STOPPED = 1;
     */
    STOPPED = 1,
    /**
     * The job is currently running.
     *
     * @generated from protobuf enum value: RUNNING = 2;
     */
    RUNNING = 2,
    /**
     * The job has successfully completed. (terminal)
     *
     * @generated from protobuf enum value: DONE = 3;
     */
    DONE = 3,
    /**
     * The job has failed. (terminal)
     *
     * @generated from protobuf enum value: FAILED = 4;
     */
    FAILED = 4,
    /**
     * The job has been explicitly cancelled. (terminal)
     *
     * @generated from protobuf enum value: CANCELLED = 5;
     */
    CANCELLED = 5,
    /**
     * The job has been updated. (terminal)
     *
     * @generated from protobuf enum value: UPDATED = 6;
     */
    UPDATED = 6,
    /**
     * The job is draining its data. (optional)
     *
     * @generated from protobuf enum value: DRAINING = 7;
     */
    DRAINING = 7,
    /**
     * The job has completed draining its data. (terminal)
     *
     * @generated from protobuf enum value: DRAINED = 8;
     */
    DRAINED = 8,
    /**
     * The job is starting up.
     *
     * @generated from protobuf enum value: STARTING = 9;
     */
    STARTING = 9,
    /**
     * The job is cancelling. (optional)
     *
     * @generated from protobuf enum value: CANCELLING = 10;
     */
    CANCELLING = 10,
    /**
     * The job is in the process of being updated. (optional)
     *
     * @generated from protobuf enum value: UPDATING = 11;
     */
    UPDATING = 11
}
/**
 * @generated from protobuf message org.apache.beam.model.job_management.v1.GetJobMetricsRequest
 */
export interface GetJobMetricsRequest {
    /**
     * @generated from protobuf field: string job_id = 1;
     */
    jobId: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.job_management.v1.GetJobMetricsResponse
 */
export interface GetJobMetricsResponse {
    /**
     * @generated from protobuf field: org.apache.beam.model.job_management.v1.MetricResults metrics = 1;
     */
    metrics?: MetricResults;
}
/**
 * All metrics for a given job.  Runners may support one or the other or both.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.MetricResults
 */
export interface MetricResults {
    /**
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.MonitoringInfo attempted = 1;
     */
    attempted: MonitoringInfo[];
    /**
     * @generated from protobuf field: repeated org.apache.beam.model.pipeline.v1.MonitoringInfo committed = 2;
     */
    committed: MonitoringInfo[];
}
/**
 * DescribePipelineOptions provides metadata about the options supported by a runner.
 * It will be used by the SDK client to validate the options specified by or
 * list available options to the user.
 * Throws error GRPC_STATUS_UNAVAILABLE if server is down
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.DescribePipelineOptionsRequest
 */
export interface DescribePipelineOptionsRequest {
}
/**
 * Type for pipeline options.
 * Types mirror those of JSON, since that's how pipeline options are serialized.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.PipelineOptionType
 */
export interface PipelineOptionType {
}
/**
 * @generated from protobuf enum org.apache.beam.model.job_management.v1.PipelineOptionType.Enum
 */
export declare enum PipelineOptionType_Enum {
    /**
     * @generated from protobuf enum value: STRING = 0;
     */
    STRING = 0,
    /**
     * @generated from protobuf enum value: BOOLEAN = 1;
     */
    BOOLEAN = 1,
    /**
     * whole numbers, see https://json-schema.org/understanding-json-schema/reference/numeric.html
     *
     * @generated from protobuf enum value: INTEGER = 2;
     */
    INTEGER = 2,
    /**
     * @generated from protobuf enum value: NUMBER = 3;
     */
    NUMBER = 3,
    /**
     * @generated from protobuf enum value: ARRAY = 4;
     */
    ARRAY = 4,
    /**
     * @generated from protobuf enum value: OBJECT = 5;
     */
    OBJECT = 5
}
/**
 * Metadata for a pipeline option.
 *
 * @generated from protobuf message org.apache.beam.model.job_management.v1.PipelineOptionDescriptor
 */
export interface PipelineOptionDescriptor {
    /**
     * (Required) The option name.
     *
     * @generated from protobuf field: string name = 1;
     */
    name: string;
    /**
     * (Required) Type of option.
     *
     * @generated from protobuf field: org.apache.beam.model.job_management.v1.PipelineOptionType.Enum type = 2;
     */
    type: PipelineOptionType_Enum;
    /**
     * (Optional) Description suitable for display / help text.
     *
     * @generated from protobuf field: string description = 3;
     */
    description: string;
    /**
     * (Optional) Default value.
     *
     * @generated from protobuf field: string default_value = 4;
     */
    defaultValue: string;
    /**
     * (Required) The group this option belongs to.
     *
     * @generated from protobuf field: string group = 5;
     */
    group: string;
}
/**
 * @generated from protobuf message org.apache.beam.model.job_management.v1.DescribePipelineOptionsResponse
 */
export interface DescribePipelineOptionsResponse {
    /**
     * List of pipeline option descriptors.
     *
     * @generated from protobuf field: repeated org.apache.beam.model.job_management.v1.PipelineOptionDescriptor options = 1;
     */
    options: PipelineOptionDescriptor[];
}
declare class PrepareJobRequest$Type extends MessageType<PrepareJobRequest> {
    constructor();
    create(value?: PartialMessage<PrepareJobRequest>): PrepareJobRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: PrepareJobRequest): PrepareJobRequest;
    internalBinaryWrite(message: PrepareJobRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.PrepareJobRequest
 */
export declare const PrepareJobRequest: PrepareJobRequest$Type;
declare class PrepareJobResponse$Type extends MessageType<PrepareJobResponse> {
    constructor();
    create(value?: PartialMessage<PrepareJobResponse>): PrepareJobResponse;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: PrepareJobResponse): PrepareJobResponse;
    internalBinaryWrite(message: PrepareJobResponse, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.PrepareJobResponse
 */
export declare const PrepareJobResponse: PrepareJobResponse$Type;
declare class RunJobRequest$Type extends MessageType<RunJobRequest> {
    constructor();
    create(value?: PartialMessage<RunJobRequest>): RunJobRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: RunJobRequest): RunJobRequest;
    internalBinaryWrite(message: RunJobRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.RunJobRequest
 */
export declare const RunJobRequest: RunJobRequest$Type;
declare class RunJobResponse$Type extends MessageType<RunJobResponse> {
    constructor();
    create(value?: PartialMessage<RunJobResponse>): RunJobResponse;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: RunJobResponse): RunJobResponse;
    internalBinaryWrite(message: RunJobResponse, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.RunJobResponse
 */
export declare const RunJobResponse: RunJobResponse$Type;
declare class CancelJobRequest$Type extends MessageType<CancelJobRequest> {
    constructor();
    create(value?: PartialMessage<CancelJobRequest>): CancelJobRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: CancelJobRequest): CancelJobRequest;
    internalBinaryWrite(message: CancelJobRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.CancelJobRequest
 */
export declare const CancelJobRequest: CancelJobRequest$Type;
declare class CancelJobResponse$Type extends MessageType<CancelJobResponse> {
    constructor();
    create(value?: PartialMessage<CancelJobResponse>): CancelJobResponse;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: CancelJobResponse): CancelJobResponse;
    internalBinaryWrite(message: CancelJobResponse, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.CancelJobResponse
 */
export declare const CancelJobResponse: CancelJobResponse$Type;
declare class JobInfo$Type extends MessageType<JobInfo> {
    constructor();
    create(value?: PartialMessage<JobInfo>): JobInfo;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: JobInfo): JobInfo;
    internalBinaryWrite(message: JobInfo, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.JobInfo
 */
export declare const JobInfo: JobInfo$Type;
declare class GetJobsRequest$Type extends MessageType<GetJobsRequest> {
    constructor();
    create(value?: PartialMessage<GetJobsRequest>): GetJobsRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: GetJobsRequest): GetJobsRequest;
    internalBinaryWrite(message: GetJobsRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.GetJobsRequest
 */
export declare const GetJobsRequest: GetJobsRequest$Type;
declare class GetJobsResponse$Type extends MessageType<GetJobsResponse> {
    constructor();
    create(value?: PartialMessage<GetJobsResponse>): GetJobsResponse;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: GetJobsResponse): GetJobsResponse;
    internalBinaryWrite(message: GetJobsResponse, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.GetJobsResponse
 */
export declare const GetJobsResponse: GetJobsResponse$Type;
declare class GetJobStateRequest$Type extends MessageType<GetJobStateRequest> {
    constructor();
    create(value?: PartialMessage<GetJobStateRequest>): GetJobStateRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: GetJobStateRequest): GetJobStateRequest;
    internalBinaryWrite(message: GetJobStateRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.GetJobStateRequest
 */
export declare const GetJobStateRequest: GetJobStateRequest$Type;
declare class JobStateEvent$Type extends MessageType<JobStateEvent> {
    constructor();
    create(value?: PartialMessage<JobStateEvent>): JobStateEvent;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: JobStateEvent): JobStateEvent;
    internalBinaryWrite(message: JobStateEvent, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.JobStateEvent
 */
export declare const JobStateEvent: JobStateEvent$Type;
declare class GetJobPipelineRequest$Type extends MessageType<GetJobPipelineRequest> {
    constructor();
    create(value?: PartialMessage<GetJobPipelineRequest>): GetJobPipelineRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: GetJobPipelineRequest): GetJobPipelineRequest;
    internalBinaryWrite(message: GetJobPipelineRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.GetJobPipelineRequest
 */
export declare const GetJobPipelineRequest: GetJobPipelineRequest$Type;
declare class GetJobPipelineResponse$Type extends MessageType<GetJobPipelineResponse> {
    constructor();
    create(value?: PartialMessage<GetJobPipelineResponse>): GetJobPipelineResponse;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: GetJobPipelineResponse): GetJobPipelineResponse;
    internalBinaryWrite(message: GetJobPipelineResponse, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.GetJobPipelineResponse
 */
export declare const GetJobPipelineResponse: GetJobPipelineResponse$Type;
declare class JobMessagesRequest$Type extends MessageType<JobMessagesRequest> {
    constructor();
    create(value?: PartialMessage<JobMessagesRequest>): JobMessagesRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: JobMessagesRequest): JobMessagesRequest;
    internalBinaryWrite(message: JobMessagesRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.JobMessagesRequest
 */
export declare const JobMessagesRequest: JobMessagesRequest$Type;
declare class JobMessage$Type extends MessageType<JobMessage> {
    constructor();
    create(value?: PartialMessage<JobMessage>): JobMessage;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: JobMessage): JobMessage;
    internalBinaryWrite(message: JobMessage, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.JobMessage
 */
export declare const JobMessage: JobMessage$Type;
declare class JobMessagesResponse$Type extends MessageType<JobMessagesResponse> {
    constructor();
    create(value?: PartialMessage<JobMessagesResponse>): JobMessagesResponse;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: JobMessagesResponse): JobMessagesResponse;
    internalBinaryWrite(message: JobMessagesResponse, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.JobMessagesResponse
 */
export declare const JobMessagesResponse: JobMessagesResponse$Type;
declare class JobState$Type extends MessageType<JobState> {
    constructor();
    create(value?: PartialMessage<JobState>): JobState;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: JobState): JobState;
    internalBinaryWrite(message: JobState, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.JobState
 */
export declare const JobState: JobState$Type;
declare class GetJobMetricsRequest$Type extends MessageType<GetJobMetricsRequest> {
    constructor();
    create(value?: PartialMessage<GetJobMetricsRequest>): GetJobMetricsRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: GetJobMetricsRequest): GetJobMetricsRequest;
    internalBinaryWrite(message: GetJobMetricsRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.GetJobMetricsRequest
 */
export declare const GetJobMetricsRequest: GetJobMetricsRequest$Type;
declare class GetJobMetricsResponse$Type extends MessageType<GetJobMetricsResponse> {
    constructor();
    create(value?: PartialMessage<GetJobMetricsResponse>): GetJobMetricsResponse;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: GetJobMetricsResponse): GetJobMetricsResponse;
    internalBinaryWrite(message: GetJobMetricsResponse, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.GetJobMetricsResponse
 */
export declare const GetJobMetricsResponse: GetJobMetricsResponse$Type;
declare class MetricResults$Type extends MessageType<MetricResults> {
    constructor();
    create(value?: PartialMessage<MetricResults>): MetricResults;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: MetricResults): MetricResults;
    internalBinaryWrite(message: MetricResults, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.MetricResults
 */
export declare const MetricResults: MetricResults$Type;
declare class DescribePipelineOptionsRequest$Type extends MessageType<DescribePipelineOptionsRequest> {
    constructor();
    create(value?: PartialMessage<DescribePipelineOptionsRequest>): DescribePipelineOptionsRequest;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: DescribePipelineOptionsRequest): DescribePipelineOptionsRequest;
    internalBinaryWrite(message: DescribePipelineOptionsRequest, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.DescribePipelineOptionsRequest
 */
export declare const DescribePipelineOptionsRequest: DescribePipelineOptionsRequest$Type;
declare class PipelineOptionType$Type extends MessageType<PipelineOptionType> {
    constructor();
    create(value?: PartialMessage<PipelineOptionType>): PipelineOptionType;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: PipelineOptionType): PipelineOptionType;
    internalBinaryWrite(message: PipelineOptionType, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.PipelineOptionType
 */
export declare const PipelineOptionType: PipelineOptionType$Type;
declare class PipelineOptionDescriptor$Type extends MessageType<PipelineOptionDescriptor> {
    constructor();
    create(value?: PartialMessage<PipelineOptionDescriptor>): PipelineOptionDescriptor;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: PipelineOptionDescriptor): PipelineOptionDescriptor;
    internalBinaryWrite(message: PipelineOptionDescriptor, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.PipelineOptionDescriptor
 */
export declare const PipelineOptionDescriptor: PipelineOptionDescriptor$Type;
declare class DescribePipelineOptionsResponse$Type extends MessageType<DescribePipelineOptionsResponse> {
    constructor();
    create(value?: PartialMessage<DescribePipelineOptionsResponse>): DescribePipelineOptionsResponse;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: DescribePipelineOptionsResponse): DescribePipelineOptionsResponse;
    internalBinaryWrite(message: DescribePipelineOptionsResponse, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.job_management.v1.DescribePipelineOptionsResponse
 */
export declare const DescribePipelineOptionsResponse: DescribePipelineOptionsResponse$Type;
/**
 * @generated ServiceType for protobuf service org.apache.beam.model.job_management.v1.JobService
 */
export declare const JobService: ServiceType;
export {};
