import type { BinaryWriteOptions } from "@protobuf-ts/runtime";
import type { IBinaryWriter } from "@protobuf-ts/runtime";
import type { BinaryReadOptions } from "@protobuf-ts/runtime";
import type { IBinaryReader } from "@protobuf-ts/runtime";
import type { PartialMessage } from "@protobuf-ts/runtime";
import { MessageType } from "@protobuf-ts/runtime";
import { Timestamp } from "../../../../../../google/protobuf/timestamp";
import { Duration } from "../../../../../../google/protobuf/duration";
/**
 * By default, all data in a PCollection is assigned to the single global
 * window. See BeamConstants for the time span this window encompasses.
 *
 * See https://beam.apache.org/documentation/programming-guide/#single-global-window
 * for additional details.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.GlobalWindowsPayload
 */
export interface GlobalWindowsPayload {
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.GlobalWindowsPayload.Enum
 */
export declare enum GlobalWindowsPayload_Enum {
    /**
     * @generated from protobuf enum value: PROPERTIES = 0;
     */
    PROPERTIES = 0
}
/**
 * A fixed time window represents a consistent duration size, non overlapping
 * time interval in the data stream.
 *
 * See https://beam.apache.org/documentation/programming-guide/#fixed-time-windows
 * for additional details.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.FixedWindowsPayload
 */
export interface FixedWindowsPayload {
    /**
     * (Required) Represents the size of the window.
     *
     * @generated from protobuf field: google.protobuf.Duration size = 1;
     */
    size?: Duration;
    /**
     * (Required) Represents the timestamp of when the first window begins.
     * Window N will start at offset + N * size.
     *
     * @generated from protobuf field: google.protobuf.Timestamp offset = 2;
     */
    offset?: Timestamp;
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.FixedWindowsPayload.Enum
 */
export declare enum FixedWindowsPayload_Enum {
    /**
     * @generated from protobuf enum value: PROPERTIES = 0;
     */
    PROPERTIES = 0
}
/**
 * A sliding time window represents time intervals in the data stream that can
 * overlap. For example, each window might capture 60 seconds worth of data, but
 * a new window starts every 30 seconds. The frequency with which sliding
 * windows begin is called the period. Therefore, our example would have a
 * window size of 60 seconds and a period of 30 seconds.
 *
 * Because multiple windows overlap, most elements in a data set will belong to
 * more than one window. This kind of windowing is useful for taking running
 * averages of data; using sliding time windows, you can compute a running
 * average of the past 60 seconds’ worth of data, updated every 30 seconds, in
 * our example.
 *
 * See https://beam.apache.org/documentation/programming-guide/#sliding-time-windows
 * for additional details.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.SlidingWindowsPayload
 */
export interface SlidingWindowsPayload {
    /**
     * (Required) Represents the size of the window.
     *
     * @generated from protobuf field: google.protobuf.Duration size = 1;
     */
    size?: Duration;
    /**
     * (Required) Represents the timestamp of when the first window begins.
     * Window N will start at offset + N * period.
     *
     * @generated from protobuf field: google.protobuf.Timestamp offset = 2;
     */
    offset?: Timestamp;
    /**
     * (Required) Represents the amount of time between each start of a window.
     *
     * @generated from protobuf field: google.protobuf.Duration period = 3;
     */
    period?: Duration;
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.SlidingWindowsPayload.Enum
 */
export declare enum SlidingWindowsPayload_Enum {
    /**
     * @generated from protobuf enum value: PROPERTIES = 0;
     */
    PROPERTIES = 0
}
/**
 * A session window function defines windows that contain elements that are
 * within a certain gap size of another element. Session windowing applies
 * on a per-key basis and is useful for data that is irregularly distributed
 * with respect to time. For example, a data stream representing user mouse
 * activity may have long periods of idle time interspersed with high
 * concentrations of clicks. If data arrives after the minimum specified gap
 * size duration, this initiates the start of a new window.
 *
 * See https://beam.apache.org/documentation/programming-guide/#session-windows
 * for additional details.
 *
 * @generated from protobuf message org.apache.beam.model.pipeline.v1.SessionWindowsPayload
 */
export interface SessionWindowsPayload {
    /**
     * (Required) Minimum duration of gaps between sessions.
     *
     * @generated from protobuf field: google.protobuf.Duration gap_size = 1;
     */
    gapSize?: Duration;
}
/**
 * @generated from protobuf enum org.apache.beam.model.pipeline.v1.SessionWindowsPayload.Enum
 */
export declare enum SessionWindowsPayload_Enum {
    /**
     * @generated from protobuf enum value: PROPERTIES = 0;
     */
    PROPERTIES = 0
}
declare class GlobalWindowsPayload$Type extends MessageType<GlobalWindowsPayload> {
    constructor();
    create(value?: PartialMessage<GlobalWindowsPayload>): GlobalWindowsPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: GlobalWindowsPayload): GlobalWindowsPayload;
    internalBinaryWrite(message: GlobalWindowsPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.GlobalWindowsPayload
 */
export declare const GlobalWindowsPayload: GlobalWindowsPayload$Type;
declare class FixedWindowsPayload$Type extends MessageType<FixedWindowsPayload> {
    constructor();
    create(value?: PartialMessage<FixedWindowsPayload>): FixedWindowsPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: FixedWindowsPayload): FixedWindowsPayload;
    internalBinaryWrite(message: FixedWindowsPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.FixedWindowsPayload
 */
export declare const FixedWindowsPayload: FixedWindowsPayload$Type;
declare class SlidingWindowsPayload$Type extends MessageType<SlidingWindowsPayload> {
    constructor();
    create(value?: PartialMessage<SlidingWindowsPayload>): SlidingWindowsPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: SlidingWindowsPayload): SlidingWindowsPayload;
    internalBinaryWrite(message: SlidingWindowsPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.SlidingWindowsPayload
 */
export declare const SlidingWindowsPayload: SlidingWindowsPayload$Type;
declare class SessionWindowsPayload$Type extends MessageType<SessionWindowsPayload> {
    constructor();
    create(value?: PartialMessage<SessionWindowsPayload>): SessionWindowsPayload;
    internalBinaryRead(reader: IBinaryReader, length: number, options: BinaryReadOptions, target?: SessionWindowsPayload): SessionWindowsPayload;
    internalBinaryWrite(message: SessionWindowsPayload, writer: IBinaryWriter, options: BinaryWriteOptions): IBinaryWriter;
}
/**
 * @generated MessageType for protobuf message org.apache.beam.model.pipeline.v1.SessionWindowsPayload
 */
export declare const SessionWindowsPayload: SessionWindowsPayload$Type;
export {};
