/**
 * Various transforms useful for asserting the expected contents of
 * PCollections, primarily for for testing.
 *
 * @packageDocumentation
 */
import * as beam from "../index";
/**
 * A PTransform that will fail the pipeline if the input PCollection does not
 * contain exactly the given elements (in any order).  Useful for writing test,
 * e.g.
 *
 *```js
 * pcoll.apply(assertDeepEqual(1, 2, 3));
 *```
 */
export declare function assertDeepEqual<T>(expected: T[]): beam.PTransform<beam.PCollection<T>, void>;
/**
 * A PTransform that will fail the pipeline if the given callback fails when
 * called with the input PCollection's elements.
 *
 * Note that the callback must not be sensitive to ordering, as the ordering
 * of the provided elements is not well determined.
 */
export declare function assertContentsSatisfies<T>(check: (actual: T[]) => void): beam.PTransform<beam.PCollection<T>, void>;
