/// <reference types="node" />
import { ChildProcess } from "child_process";
export interface Service {
    start: () => Promise<string>;
    stop: () => Promise<void>;
}
export declare class ExternalService implements Service {
    address: string;
    constructor(address: string);
    start(): Promise<string>;
    stop(): Promise<void>;
}
declare class SubprocessServiceCache {
    parent?: SubprocessServiceCache;
    services: Map<string, SubprocessService>;
    constructor(parent?: SubprocessServiceCache | undefined);
    put(key: string, service: SubprocessService): void;
    get(key: string): SubprocessService | undefined;
    stopAll(): Promise<void>;
}
export declare class SubprocessService {
    static cache?: SubprocessServiceCache;
    process: ChildProcess;
    cmd: string;
    args: string[];
    name: string;
    address?: string;
    cached: boolean;
    constructor(cmd: string, args: string[], name?: string | undefined);
    static freePort(): Promise<number>;
    static createCache(): SubprocessServiceCache;
    key(): string;
    start(): Promise<string>;
    stop(): Promise<void>;
    portReady(port: any, host: any, timeoutMs: any, iterMs?: number): Promise<void>;
}
export declare function serviceProviderFromJavaGradleTarget(gradleTarget: string, args?: string[] | undefined): () => Promise<Service>;
export declare class JavaJarService extends SubprocessService {
    static APACHE_REPOSITORY: string;
    static BEAM_GROUP_ID: string;
    static JAR_CACHE: any;
    constructor(jar: string, args?: string[] | undefined, name?: string | undefined);
    static cachedJar(urlOrPath: string, cacheDir?: string): Promise<string>;
    static gradleToJar(gradleTarget: string, appendix?: string | undefined, version?: string): Promise<string>;
    static mavenJarUrl(artifactId: string, version: string, classifier?: string | undefined, appendix?: string | undefined, repo?: string, groupId?: string): Promise<string>;
    static jarName(artifactId: string, version: string, classifier: string | undefined, appendix: string | undefined): string;
}
export declare class PythonService extends SubprocessService {
    static VENV_CACHE: any;
    static whichPython(): string;
    static beamPython(): string;
    static forModule(module: string, args?: string[]): Service;
    private constructor();
}
export {};
