import { MonitoringInfo } from "../proto/metrics";
export interface MetricSpec {
    metricType: string;
    name: string;
}
/**
 * A MetricCell holds the concrete value of a metric at runtime.
 *
 * Different types of metrics will have different types of MetricCells,
 * with the relationship being stored in the metricTypes map.
 */
interface MetricCell<T> {
    update: (value: T) => void;
    reset: () => void;
    toEmptyMonitoringInfo: () => MonitoringInfo;
    payload: () => Uint8Array;
    loadFromPayload: (paylaod: Uint8Array) => void;
    merge(other: MetricCell<T>): any;
    extract(): any;
}
/**
 * A ScopedMetricCell is a MetricCell together with its identifier(s).
 */
declare class ScopedMetricCell<T> {
    key: string;
    value: MetricCell<unknown>;
    name?: string | undefined;
    transformId?: string | undefined;
    pcollectionId?: string | undefined;
    is_set: boolean;
    constructor(key: string, value: MetricCell<unknown>, name?: string | undefined, transformId?: string | undefined, pcollectionId?: string | undefined);
    toEmptyMonitoringInfo(): MonitoringInfo;
    update(value: T): void;
    reset(): void;
}
/**
 * A MetricsContainer holds a set of metrics for a particular bundle.
 *
 * It can be re-used, but must be reset() between bundles.
 */
export declare class MetricsContainer {
    metrics: Map<string, ScopedMetricCell<unknown>>;
    getMetric(transformId: string | undefined, pcollectionId: string | undefined, spec: MetricSpec): ScopedMetricCell<unknown>;
    elementCountMetric(pcollectionId: string): ScopedMetricCell<unknown>;
    monitoringData(shortIdCache: MetricsShortIdCache): Map<string, Uint8Array>;
    reset(): void;
}
export declare class MetricsShortIdCache {
    private idToInfo;
    private keyToId;
    getShortId(metric: ScopedMetricCell<unknown>): string;
    asMonitoringInfo(id: string, payload?: Uint8Array | undefined): MonitoringInfo;
}
export declare function aggregateMetrics(infos: MonitoringInfo[], urn: string): Map<string, any>;
export {};
